@@ -1,11 +1,4 @@
-
-def convert_to(obj: object, new_dto_class):
-    """
-    Recebendo um objeto qualquer (parâmetro "obj"), e uma classe qualquer (parâmetro "new_dto_class"),
-    este método cria uma instância da classe "new_dto_class", e copia todos os atributos do objeto
-    "obj" para a nova instância, desde que haja um atributo com mesmo nome na classe de destino.
-    """
-
+def _convert_to(obj: object, new_dto_class):
     new_obj = new_dto_class()
 
     for attribute in obj.__dict__:
@@ -19,3 +12,19 @@ def convert_to(obj: object, new_dto_class):
         setattr(new_obj, attribute, attr_origem)
 
     return new_obj
+
+
+def convert_to(obj: object, new_dto_class):
+    """
+    Recebendo um objeto qualquer (parâmetro "obj"), e uma classe qualquer (parâmetro "new_dto_class"),
+    este método cria uma instância da classe "new_dto_class", e copia todos os atributos do objeto
+    "obj" para a nova instância, desde que haja um atributo com mesmo nome na classe de destino.
+
+    Este método também está preparado para receber uma lista de objetos, e converter para uma nova
+    lista de objetos do tipo "new_dto_class".
+    """
+
+    if isinstance(obj, list):
+        return [_convert_to(item, new_dto_class) for item in obj]
+    else:
+        return _convert_to(obj, new_dto_class)
